@@ -1,6 +1,6 @@
 #include "message.ih"
 
-char const *message_programName()
+char const *message_programName(void)
 {
     return m_message.d_program_name;
 }
