@@ -1,5 +1,5 @@
-#ifndef _INCLUDED_POSTQUEUE_H_
-#define _INCLUDED_POSTQUEUE_H_
+#ifndef INCLUDED_POSTQUEUE_H_
+#define INCLUDED_POSTQUEUE_H_
 
 #if 0
 
