@@ -4,5 +4,5 @@ void string_assign(register String *sp, register char const *txt)
 {
     free(sp->d_str);
 
-    s_init(sp, txt);
+    s_init(sp, txt ? txt : s_empty);
 }
